@@ -60,14 +60,11 @@ impl VisitMut for KeywordRenamer {
     }
 
     fn visit_mut_expr(&mut self, n: &mut Expr) {
-        match n {
-            Expr::Ident(n) => {
-                if let Some(renamed) = self.renamed(&n) {
-                    *n = renamed;
-                }
-                return;
+        if let Expr::Ident(n) = n {
+            if let Some(renamed) = self.renamed(n) {
+                *n = renamed;
             }
-            _ => {}
+            return;
         }
 
         n.visit_mut_children_with(self);
@@ -97,44 +94,38 @@ impl VisitMut for KeywordRenamer {
     fn visit_mut_object_pat_prop(&mut self, n: &mut ObjectPatProp) {
         n.visit_mut_children_with(self);
 
-        match n {
-            ObjectPatProp::Assign(pat) => {
-                if let Some(renamed) = self.renamed(&pat.key) {
-                    match &mut pat.value {
-                        Some(default) => {
-                            *n = ObjectPatProp::KeyValue(KeyValuePatProp {
-                                key: PropName::Ident(pat.key.take()),
-                                value: Box::new(Pat::Assign(AssignPat {
-                                    span: pat.span,
-                                    left: Box::new(Pat::Ident(renamed.into())),
-                                    right: default.take(),
-                                    type_ann: None,
-                                })),
-                            });
-                        }
-                        None => {
-                            *n = ObjectPatProp::KeyValue(KeyValuePatProp {
-                                key: PropName::Ident(pat.key.take()),
-                                value: Box::new(Pat::Ident(renamed.into())),
-                            })
-                        }
+        if let ObjectPatProp::Assign(pat) = n {
+            if let Some(renamed) = self.renamed(&pat.key) {
+                match &mut pat.value {
+                    Some(default) => {
+                        *n = ObjectPatProp::KeyValue(KeyValuePatProp {
+                            key: PropName::Ident(pat.key.take()),
+                            value: Box::new(Pat::Assign(AssignPat {
+                                span: pat.span,
+                                left: Box::new(Pat::Ident(renamed.into())),
+                                right: default.take(),
+                                type_ann: None,
+                            })),
+                        });
+                    }
+                    None => {
+                        *n = ObjectPatProp::KeyValue(KeyValuePatProp {
+                            key: PropName::Ident(pat.key.take()),
+                            value: Box::new(Pat::Ident(renamed.into())),
+                        })
                     }
                 }
             }
-            _ => {}
         }
     }
 
     fn visit_mut_pat(&mut self, n: &mut Pat) {
-        match n {
-            Pat::Ident(n) => {
-                if let Some(renamed) = self.renamed(&n.id) {
-                    *n = renamed.into();
-                }
-
-                return;
+        if let Pat::Ident(n) = n {
+            if let Some(renamed) = self.renamed(&n.id) {
+                *n = renamed.into();
             }
-            _ => {}
+
+            return;
         }
         n.visit_mut_children_with(self);
     }
@@ -151,7 +142,7 @@ impl VisitMut for KeywordRenamer {
     fn visit_mut_prop(&mut self, n: &mut Prop) {
         match n {
             Prop::Shorthand(i) => {
-                if let Some(renamed) = self.renamed(&i) {
+                if let Some(renamed) = self.renamed(i) {
                     *n = Prop::KeyValue(KeyValueProp {
                         key: PropName::Ident(i.clone()),
                         value: Box::new(Expr::Ident(renamed)),
